@@ -13,7 +13,6 @@
 # limitations under the License.
 
 import numpy as np
-import pandas as pd
 
 
 def n_records(data):
@@ -204,23 +203,23 @@ def n_keywords(data):
     return np.average([len(keywords) for keywords in data.keywords])
 
 
-def n_duplicates(data):
+def n_duplicates(data, pid='doi'):
     """Number of duplicates.
 
     Duplicate detection can be a very challenging task. Multiple
-    algotihms can be used and results can be vary.
+    algorithms can be used and results can be vary.
 
     Arguments
     ---------
     data: asreview.data.ASReviewData
         An ASReviewData object with the records.
+    pid: string
+        Which persistent identifier (PID) to use for deduplication.
+        Default is 'doi'.
 
     Return
     ------
     int:
         Number of duplicates
     """
-    s = pd.Series(data.texts).str.replace("[^A-Za-z0-9]", "", regex=True) \
-        .str.lower()
-
-    return int(s.duplicated().sum())
+    return int(data.duplicated(pid).sum())
