@@ -1,6 +1,20 @@
+# Copyright 2019-2022 The ASReview Authors. All Rights Reserved.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 from asreview.entry_points.base import BaseEntryPoint
 from asreview.models.balance import list_balance_strategies
-from asreview.models import list_classifiers
+from asreview.models.classifiers import list_classifiers
 from asreview.models.feature_extraction import list_feature_extraction
 from asreview.models.query import list_query_strategies
 
@@ -12,7 +26,12 @@ def _format_algorithm(values, name, description):
     result = []
 
     for x in values:
-        result.append(" " * 22 + f"{x}")
+        if hasattr(x, "label"):
+            result.append(
+                " " * 22 + f"{x.name}" + " " * (16 - len(x.name)) + f"{x.label}"
+            )
+        else:
+            result.append(" " * 22 + f"{x.name}")
 
     s += "\n".join(result)
     s += "\n\n"
@@ -21,12 +40,20 @@ def _format_algorithm(values, name, description):
 
 
 class AlgorithmsEntryPoint(BaseEntryPoint):
+    """Entry point to list available algorithms in ASReview LAB."""
     description = "Available active learning algorithms for ASReview."
 
     def execute(self, argv):
 
         s = "Available active learning algorithms for ASReview. \n\n"
 
+        # feature_extraction
+        s += _format_algorithm(
+            values=list_feature_extraction(),
+            name="feature_extraction",
+            description="feature extraction algorithms"
+        )
+
         # classifiers
         s += _format_algorithm(
             values=list_classifiers(),
@@ -48,11 +75,4 @@ class AlgorithmsEntryPoint(BaseEntryPoint):
             description="balance strategies"
         )
 
-        # feature_extraction
-        s += _format_algorithm(
-            values=list_feature_extraction(),
-            name="feature_extraction",
-            description="feature extraction algorithms"
-        )
-
         print(s)
