@@ -1,4 +1,4 @@
-# Copyright 2019-2020 The ASReview Authors. All Rights Reserved.
+# Copyright 2019-2022 The ASReview Authors. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -101,9 +101,16 @@ def format_record(record, use_cli_colors=True):
     else:
         abstract = ""
 
-    return ("\n\n----------------------------------"
-            f"\n{title}{authors}{abstract}"
-            "----------------------------------\n\n")
+    if record.included == 0:
+        label = "IRRELEVANT"
+    elif record.included == 1:
+        label = "RELEVANT"
+    else:
+        label = ""
+
+    header = f"---{record.record_id}---{label}---"
+
+    return (f"\n{header:-<60}\n{title}{authors}{abstract}")
 
 
 class PaperRecord():
@@ -119,6 +126,8 @@ class PaperRecord():
         Paper abstract.
     authors: str, list
         Authors of the paper.
+    notes: str, list
+        Notes of the paper.
     keywords: str, list
         Keywords of the paper.
     label: int
@@ -131,7 +140,14 @@ class PaperRecord():
     def __init__(self, record_id, column_spec={}, **kwargs):
 
         for attr in [
-                "title", "abstract", "authors", "keywords", "doi", "included"
+            "title",
+            "abstract",
+            "authors",
+            "notes",
+            "keywords",
+            "doi",
+            "url",
+            "included",
         ]:
             if attr in column_spec:
                 col = column_spec[attr]
@@ -154,7 +170,7 @@ class PaperRecord():
         self.extra_fields = kwargs
 
         for attr, val in self.extra_fields.items():
-            if pd.isna(val):
+            if not isinstance(val, list) and pd.isna(val):
                 self.extra_fields[attr] = None
 
     def __str__(self):
