@@ -12,18 +12,20 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import io
 import logging
 import re
+from urllib.request import urlopen
 
 import pandas
 import rispy
 
 from asreview.io.utils import _standardize_dataframe
+from asreview.utils import is_url
 
 
-class RISReader():
-    """RIS file reader.
-    """
+class RISReader:
+    """RIS file reader."""
 
     read_format = [".ris", ".txt"]
     write_format = [".csv", ".tsv", ".xlsx", ".ris"]
@@ -47,7 +49,7 @@ class RISReader():
             new_notes = []
             for v in note_list:
                 try:
-                    new_notes.append(re.sub(r'^<p>|<\/p>$', '', v))
+                    new_notes.append(re.sub(r"^<p>|<\/p>$", "", v))
                 except Exception:
                     new_notes.append(v)
             return new_notes
@@ -80,17 +82,13 @@ class RISReader():
 
         # Create lists of lists for ASReview references
         asreview_refs = [re.findall(regex, note) for note in note_list]
-        asreview_refs_list = [
-            item for sublist in asreview_refs for item in sublist
-        ]
+        asreview_refs_list = [item for sublist in asreview_refs for item in sublist]
 
         if len(asreview_refs_list) > 0:
             # Create lists of lists for notes without references
             asreview_new_notes = [re.sub(regex, "", note) for note in note_list]
             # Remove empty elements from list
-            asreview_new_notes[:] = [
-                item for item in asreview_new_notes if item != ""
-            ]
+            asreview_new_notes[:] = [item for item in asreview_new_notes if item != ""]
             label = asreview_refs_list[-1]
 
             # Check for the label and return proper values for internal representation
@@ -124,20 +122,38 @@ class RISReader():
         ValueError
             File with unrecognized encoding is used as input.
         """
-        encodings = ['utf-8', 'utf-8-sig', 'ISO-8859-1']
+        encodings = ["utf-8", "utf-8-sig", "ISO-8859-1"]
         entries = None
-        for encoding in encodings:
-            try:
-                with open(fp, 'r', encoding=encoding) as bibliography_file:
-                    entries = list(
-                        rispy.load(bibliography_file, skip_unknown_tags=True))
-                    break
-            except UnicodeDecodeError:
-                pass
-            except IOError as e:
-                logging.warning(e)
         if entries is None:
-            raise ValueError("Cannot find proper encoding for data file.")
+            if is_url(fp):
+                url_input = urlopen(fp)
+            for encoding in encodings:
+                if is_url(fp):
+                    try:
+                        bibliography_file = io.StringIO(
+                            url_input.read().decode(encoding)
+                        )
+
+                        entries = list(
+                            rispy.load(bibliography_file, skip_unknown_tags=True)
+                        )
+                        bibliography_file.close()
+                        break
+                    except UnicodeDecodeError:
+                        pass
+                else:
+                    try:
+                        with open(fp, "r", encoding=encoding) as bibliography_file:
+                            entries = list(
+                                rispy.load(bibliography_file, skip_unknown_tags=True)
+                            )
+                            break
+                    except UnicodeDecodeError:
+                        pass
+                    except IOError as e:
+                        logging.warning(e)
+            if entries is None:
+                raise ValueError("Cannot find proper encoding for data file.")
 
         # Turn the entries dictionary into a Pandas dataframe
         df = pandas.DataFrame(entries)
@@ -147,9 +163,10 @@ class RISReader():
             # Strip Zotero XHTML <p> tags on "notes"
             df["notes"] = df["notes"].apply(cls._strip_zotero_p_tags)
             # Split "included" from "notes"
-            df[["included", "notes"
-                ]] = pandas.DataFrame(df["notes"].apply(cls._label_parser).tolist(),
-                                      columns=["included", "notes"])
+            df[["included", "notes"]] = pandas.DataFrame(
+                df["notes"].apply(cls._label_parser).tolist(),
+                columns=["included", "notes"],
+            )
             # Return the standardised dataframe with label and notes separated
             return _standardize_dataframe(df)
         else:
