@@ -1,4 +1,4 @@
-# Copyright 2019-2021 The ASReview Authors. All Rights Reserved.
+# Copyright 2019-2022 The ASReview Authors. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -12,7 +12,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from math import log, floor
+from math import floor
+from math import log
 
 import numpy as np
 
@@ -22,7 +23,7 @@ from asreview.utils import get_random_state
 
 
 class DoubleBalance(BaseBalance):
-    """Double balance strategy.
+    """Double balance strategy (``double``).
 
     Class to get the two way rebalancing function and arguments.
     It super samples ones depending on the number of 0's and total number
@@ -65,7 +66,7 @@ class DoubleBalance(BaseBalance):
         self.fallback_model = SimpleBalance()
         self._random_state = get_random_state(random_state)
 
-    def sample(self, X, y, train_idx, shared):
+    def sample(self, X, y, train_idx):
         """Resample the training data.
 
         Arguments
@@ -76,8 +77,6 @@ class DoubleBalance(BaseBalance):
             Labels for all papers.
         train_idx: numpy.ndarray
             Training indices, that is all papers that have been reviewed.
-        shared: dict
-            Dictionary to share data between balancing models and other models.
 
         Returns
         -------
@@ -90,7 +89,7 @@ class DoubleBalance(BaseBalance):
 
         # Fall back to simple sampling if we have only ones or zeroes.
         if len(one_idx) == 0 or len(zero_idx) == 0:
-            self.fallback_model.sample(X, y, train_idx, shared)
+            self.fallback_model.sample(X, y, train_idx)
 
         n_one = len(one_idx)
         n_zero = len(zero_idx)
@@ -158,7 +157,7 @@ def fill_training(src_idx, n_train, random_state):
     """Copy/sample until there are n_train indices sampled/copied.
     """
     # Number of copies needed.
-    n_copy = np.int(n_train / len(src_idx))
+    n_copy = int(n_train / len(src_idx))
     # For the remainder, use sampling.
     n_sample = n_train - n_copy * len(src_idx)
 
