@@ -1,4 +1,4 @@
-# Copyright 2019-2021 The ASReview Authors. All Rights Reserved.
+# Copyright 2019-2022 The ASReview Authors. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,8 +17,8 @@ import logging
 import numpy as np
 
 from asreview.models.balance.base import BaseBalance
-from asreview.models.balance.double import _one_weight
 from asreview.models.balance.double import DoubleBalance
+from asreview.models.balance.double import _one_weight
 from asreview.models.balance.double import _zero_weight
 from asreview.models.balance.double import fill_training
 from asreview.models.balance.double import random_round
@@ -26,7 +26,9 @@ from asreview.utils import get_random_state
 
 
 class TripleBalance(BaseBalance):
-    """Triple balance strategy.
+    """Triple balance strategy (``triple``).
+
+    Broken. Only for internal and experimental use.
 
     This divides the training data into three sets: included papers, excluded
     papers found with random sampling and papers found with max sampling. They
@@ -74,6 +76,7 @@ class TripleBalance(BaseBalance):
                  shuffle=True,
                  random_state=None):
         """Initialize the triple balance strategy."""
+
         super(TripleBalance, self).__init__()
         self.a = a
         self.alpha = alpha
@@ -105,8 +108,8 @@ class TripleBalance(BaseBalance):
         numpy.ndarray,numpy.ndarray:
             X_train, y_train: the resampled matrix, labels.
         """
-        max_idx = np.array(shared["query_src"].get("max", []), dtype=np.int)
-        rand_idx = np.array([], dtype=np.int)
+        max_idx = np.array(shared["query_src"].get("max", []), dtype=int)
+        rand_idx = np.array([], dtype=int)
         for qtype in shared["query_src"]:
             if qtype != "max":
                 rand_idx = np.append(rand_idx, shared["query_src"][qtype])
