@@ -1,4 +1,4 @@
-# Copyright 2019-2021 The ASReview Authors. All Rights Reserved.
+# Copyright 2019-2022 The ASReview Authors. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -21,7 +21,7 @@ from asreview.utils import get_random_state
 
 
 class UndersampleBalance(BaseBalance):
-    """Undersampling balance strategy.
+    """Undersampling balance strategy (``undersample``).
 
     This undersamples the data, leaving out excluded papers so that the
     included and excluded papers are in some particular ratio (closer to one).
@@ -42,7 +42,7 @@ class UndersampleBalance(BaseBalance):
         self.ratio = ratio
         self._random_state = get_random_state(random_state)
 
-    def sample(self, X, y, train_idx, shared):
+    def sample(self, X, y, train_idx):
         """Resample the training data.
 
         Arguments
@@ -53,8 +53,6 @@ class UndersampleBalance(BaseBalance):
             Labels for all papers.
         train_idx: numpy.ndarray
             Training indices, that is all papers that have been reviewed.
-        shared: dict
-            Dictionary to share data between balancing models and other models.
 
         Returns
         -------
