@@ -1,4 +1,4 @@
-# Copyright 2019-2021 The ASReview Authors. All Rights Reserved.
+# Copyright 2019-2022 The ASReview Authors. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,12 +17,12 @@ import logging
 from sklearn.linear_model import LogisticRegression
 
 from asreview.models.classifiers.base import BaseTrainClassifier
-from asreview.utils import _set_class_weight
+from asreview.models.classifiers.utils import _set_class_weight
 
 
 class LogisticClassifier(BaseTrainClassifier):
     """
-    Logistic regression classifier.
+    Logistic regression classifier (``logistic``).
 
     The Logistic regressions classifier is an implementation based
     on the sklearn Logistic regressions classifier.
