@@ -1,4 +1,4 @@
-# Copyright 2019-2021 The ASReview Authors. All Rights Reserved.
+# Copyright 2019-2022 The ASReview Authors. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,13 +14,12 @@
 
 import logging
 
-
 try:
     import tensorflow as tf
+    from tensorflow.keras import regularizers
     from tensorflow.keras.layers import Dense
     from tensorflow.keras.models import Sequential
     from tensorflow.keras.wrappers.scikit_learn import KerasClassifier
-    from tensorflow.keras import regularizers
 except ImportError:
     TF_AVAILABLE = False
 else:
@@ -32,10 +31,9 @@ else:
 
 import scipy
 
-
 from asreview.models.classifiers.base import BaseTrainClassifier
 from asreview.models.classifiers.lstm_base import _get_optimizer
-from asreview.utils import _set_class_weight
+from asreview.models.classifiers.utils import _set_class_weight
 
 
 def _check_tensorflow():
@@ -46,7 +44,7 @@ def _check_tensorflow():
 
 
 class NN2LayerClassifier(BaseTrainClassifier):
-    """Fully connected neural network (2 hidden layers) classifier.
+    """Fully connected neural network (2 hidden layers) classifier (``nn-2-layer``).
 
     Neural network with two hidden, dense layers of the same size.
 
