@@ -1,4 +1,4 @@
-# Copyright 2019-2021 The ASReview Authors. All Rights Reserved.
+# Copyright 2019-2022 The ASReview Authors. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,12 +15,12 @@
 from sklearn.svm import SVC
 
 from asreview.models.classifiers.base import BaseTrainClassifier
-from asreview.utils import _set_class_weight
+from asreview.models.classifiers.utils import _set_class_weight
 
 
 class SVMClassifier(BaseTrainClassifier):
     """
-    Support vector machine classifier.
+    Support vector machine classifier (``svm``).
 
     The Support Vector Machine classifier is an implementation based
     on the sklearn Support Vector Machine classifier.
