@@ -1,4 +1,4 @@
-# Copyright 2019-2021 The ASReview Authors. All Rights Reserved.
+# Copyright 2019-2022 The ASReview Authors. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,7 +18,7 @@ from asreview.models.feature_extraction.base import BaseFeatureExtraction
 
 
 class Tfidf(BaseFeatureExtraction):
-    """TF-IDF feature extraction technique.
+    """TF-IDF feature extraction technique (``tfidf``).
 
     Use the standard TF-IDF (Term Frequency-Inverse Document Frequency) feature
     extraction technique from `SKLearn <https://scikit-learn.org/stable/modules/
