@@ -1,4 +1,4 @@
-# Copyright 2019-2020 The ASReview Authors. All Rights Reserved.
+# Copyright 2019-2022 The ASReview Authors. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -12,26 +12,25 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import logging
 import os
 from configparser import ConfigParser
-import logging
 
 from asreview.config import DEFAULT_N_INSTANCES
-from asreview.models.classifiers import get_classifier
 from asreview.models.balance import get_balance_model
-from asreview.models.query import get_query_model
+from asreview.models.classifiers import get_classifier
 from asreview.models.feature_extraction import get_feature_model
+from asreview.models.query import get_query_model
+from asreview.types import type_n_queries
 from asreview.utils import pretty_format
 
 SETTINGS_TYPE_DICT = {
-    "data_name": str,
     "model": str,
     "query_strategy": str,
     "balance_strategy": str,
     "feature_extraction": str,
-    "n_papers": int,
     "n_instances": int,
-    "n_queries": int,
+    "stop_if": type_n_queries,
     "n_prior_included": int,
     "n_prior_excluded": int,
     "mode": str,
@@ -80,49 +79,50 @@ class ASReviewSettings(object):
     of its contents.
     """
     def __init__(self,
-                 mode,
                  model,
                  query_strategy,
                  balance_strategy,
                  feature_extraction,
                  n_instances=DEFAULT_N_INSTANCES,
-                 n_queries=None,
-                 n_papers=None,
+                 stop_if=None,
                  n_prior_included=None,
                  n_prior_excluded=None,
-                 abstract_only=False,
                  as_data=None,
                  model_param={},
                  query_param={},
                  balance_param={},
                  feature_param={},
-                 data_name=None,
-                 data_fp=None):
+                 data_fp=None,
+                 n_queries=None,
+                 abstract_only=False,  # deprecated
+                 mode=None,  # deprecated
+                 n_papers=None,  # deprecated
+                 data_name=None  # deprecated
+                 ):
 
-        self.mode = mode
         self.model = model
         self.query_strategy = query_strategy
         self.balance_strategy = balance_strategy
         self.feature_extraction = feature_extraction
         self.n_instances = n_instances
-        self.n_queries = n_queries
-        self.n_papers = n_papers
+        self.stop_if = stop_if
         self.n_prior_included = n_prior_included
         self.n_prior_excluded = n_prior_excluded
-        self.abstract_only = abstract_only
         self.as_data = as_data
         self.model_param = model_param
-        self.query_param = query_param
+        if query_strategy == "max_random":
+            query_param_copy = query_param.copy()
+            try:
+                del query_param_copy["strategy_1"]
+                del query_param_copy["strategy_2"]
+            except KeyError:
+                pass
+            self.query_param = query_param_copy
+        else:
+            self.query_param = query_param
         self.balance_param = balance_param
         self.feature_param = feature_param
 
-        if data_name:
-            self.data_name = data_name
-        elif data_fp:
-            self.data_name = os.path.basename(data_fp)
-        else:
-            self.data_name = "unknown"
-
     def __str__(self):
         return pretty_format(self.to_dict())
 
