@@ -1,4 +1,4 @@
-# Copyright 2019-2020 The ASReview Authors. All Rights Reserved.
+# Copyright 2019-2022 The ASReview Authors. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -29,6 +29,12 @@ def type_n_queries(value):
         return value
     else:
         try:
-            return int(value)
+            value_i = int(value)
+
+            # convert -1 to None
+            if value_i == -1:
+                return None
+
+            return value_i
         except ValueError:
-            raise ValueError("Value for n_queries is not 'min' or a valid integer")
+            raise ValueError("Expected 'min' or a valid integer")
